==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/button/ButtonsMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class ButtonsMessageBuilder {
    private java.util.Optional<it.auties.whatsapp.model.message.button.ButtonsMessageHeaderText> headerText;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.DocumentMessage> headerDocument;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.ImageMessage> headerImage;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.VideoOrGifMessage> headerVideo;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.LocationMessage> headerLocation;
    private java.util.Optional<java.lang.String> body;
    private java.util.Optional<java.lang.String> footer;
    private java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo;
    private java.util.List<it.auties.whatsapp.model.button.base.Button> buttons;
    private it.auties.whatsapp.model.message.button.ButtonsMessageHeader.Type headerType;

    public ButtonsMessageBuilder() {
        headerText = java.util.Optional.empty();
        headerDocument = java.util.Optional.empty();
        headerImage = java.util.Optional.empty();
        headerVideo = java.util.Optional.empty();
        headerLocation = java.util.Optional.empty();
        body = java.util.Optional.empty();
        footer = java.util.Optional.empty();
        contextInfo = java.util.Optional.empty();
        buttons = new java.util.ArrayList<it.auties.whatsapp.model.button.base.Button>();
        headerType = null;
    }

    public ButtonsMessageBuilder headerText(java.util.Optional<it.auties.whatsapp.model.message.button.ButtonsMessageHeaderText> headerText) {
        this.headerText = headerText;
        return this;
    }
    public ButtonsMessageBuilder headerText(it.auties.whatsapp.model.message.button.ButtonsMessageHeaderText headerText) {
        this.headerText = java.util.Optional.ofNullable(headerText);
        return this;
    }
    public ButtonsMessageBuilder headerDocument(java.util.Optional<it.auties.whatsapp.model.message.standard.DocumentMessage> headerDocument) {
        this.headerDocument = headerDocument;
        return this;
    }
    public ButtonsMessageBuilder headerDocument(it.auties.whatsapp.model.message.standard.DocumentMessage headerDocument) {
        this.headerDocument = java.util.Optional.ofNullable(headerDocument);
        return this;
    }
    public ButtonsMessageBuilder headerImage(java.util.Optional<it.auties.whatsapp.model.message.standard.ImageMessage> headerImage) {
        this.headerImage = headerImage;
        return this;
    }
    public ButtonsMessageBuilder headerImage(it.auties.whatsapp.model.message.standard.ImageMessage headerImage) {
        this.headerImage = java.util.Optional.ofNullable(headerImage);
        return this;
    }
    public ButtonsMessageBuilder headerVideo(java.util.Optional<it.auties.whatsapp.model.message.standard.VideoOrGifMessage> headerVideo) {
        this.headerVideo = headerVideo;
        return this;
    }
    public ButtonsMessageBuilder headerVideo(it.auties.whatsapp.model.message.standard.VideoOrGifMessage headerVideo) {
        this.headerVideo = java.util.Optional.ofNullable(headerVideo);
        return this;
    }
    public ButtonsMessageBuilder headerLocation(java.util.Optional<it.auties.whatsapp.model.message.standard.LocationMessage> headerLocation) {
        this.headerLocation = headerLocation;
        return this;
    }
    public ButtonsMessageBuilder headerLocation(it.auties.whatsapp.model.message.standard.LocationMessage headerLocation) {
        this.headerLocation = java.util.Optional.ofNullable(headerLocation);
        return this;
    }
    public ButtonsMessageBuilder body(java.util.Optional<java.lang.String> body) {
        this.body = body;
        return this;
    }
    public ButtonsMessageBuilder body(java.lang.String body) {
        this.body = java.util.Optional.ofNullable(body);
        return this;
    }
    public ButtonsMessageBuilder footer(java.util.Optional<java.lang.String> footer) {
        this.footer = footer;
        return this;
    }
    public ButtonsMessageBuilder footer(java.lang.String footer) {
        this.footer = java.util.Optional.ofNullable(footer);
        return this;
    }
    public ButtonsMessageBuilder contextInfo(java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public ButtonsMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = java.util.Optional.ofNullable(contextInfo);
        return this;
    }
    public ButtonsMessageBuilder buttons(java.util.List<it.auties.whatsapp.model.button.base.Button> buttons) {
        this.buttons = buttons;
        return this;
    }
    public ButtonsMessageBuilder headerType(it.auties.whatsapp.model.message.button.ButtonsMessageHeader.Type headerType) {
        this.headerType = headerType;
        return this;
    }

    public it.auties.whatsapp.model.message.button.ButtonsMessage build() {
        return new it.auties.whatsapp.model.message.button.ButtonsMessage(headerText, headerDocument, headerImage, headerVideo, headerLocation, body, footer, contextInfo, buttons, headerType);
    }
}

==> cobalt-0.0.2-sources.jar: it/auties/whatsapp/model/message/button/ButtonsMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class ButtonsMessageBuilder {
    private it.auties.whatsapp.model.message.button.ButtonsMessageHeaderText headerText;
    private it.auties.whatsapp.model.message.standard.DocumentMessage headerDocument;
    private it.auties.whatsapp.model.message.standard.ImageMessage headerImage;
    private it.auties.whatsapp.model.message.standard.VideoOrGifMessage headerVideo;
    private it.auties.whatsapp.model.message.standard.LocationMessage headerLocation;
    private java.lang.String body;
    private java.lang.String footer;
    private it.auties.whatsapp.model.info.ContextInfo contextInfo;
    private java.util.List<it.auties.whatsapp.model.button.base.Button> buttons;
    private it.auties.whatsapp.model.message.button.ButtonsMessageHeader.Type headerType;

    public ButtonsMessageBuilder() {
        headerText = null;
        headerDocument = null;
        headerImage = null;
        headerVideo = null;
        headerLocation = null;
        body = null;
        footer = null;
        contextInfo = null;
        buttons = new java.util.ArrayList<it.auties.whatsapp.model.button.base.Button>();
        headerType = null;
    }

    public ButtonsMessageBuilder headerText(it.auties.whatsapp.model.message.button.ButtonsMessageHeaderText headerText) {
        this.headerText = headerText;
        return this;
    }
    public ButtonsMessageBuilder headerDocument(it.auties.whatsapp.model.message.standard.DocumentMessage headerDocument) {
        this.headerDocument = headerDocument;
        return this;
    }
    public ButtonsMessageBuilder headerImage(it.auties.whatsapp.model.message.standard.ImageMessage headerImage) {
        this.headerImage = headerImage;
        return this;
    }
    public ButtonsMessageBuilder headerVideo(it.auties.whatsapp.model.message.standard.VideoOrGifMessage headerVideo) {
        this.headerVideo = headerVideo;
        return this;
    }
    public ButtonsMessageBuilder headerLocation(it.auties.whatsapp.model.message.standard.LocationMessage headerLocation) {
        this.headerLocation = headerLocation;
        return this;
    }
    public ButtonsMessageBuilder body(java.lang.String body) {
        this.body = body;
        return this;
    }
    public ButtonsMessageBuilder footer(java.lang.String footer) {
        this.footer = footer;
        return this;
    }
    public ButtonsMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public ButtonsMessageBuilder buttons(java.util.List<it.auties.whatsapp.model.button.base.Button> buttons) {
        this.buttons = buttons;
        return this;
    }
    public ButtonsMessageBuilder headerType(it.auties.whatsapp.model.message.button.ButtonsMessageHeader.Type headerType) {
        this.headerType = headerType;
        return this;
    }

    public it.auties.whatsapp.model.message.button.ButtonsMessage build() {
        return new it.auties.whatsapp.model.message.button.ButtonsMessage(headerText, headerDocument, headerImage, headerVideo, headerLocation, body, footer, contextInfo, buttons, headerType);
    }
}
